author_info = (("Mehdi Kamani", "itsmehdi97@gmail.com"),)

package_info = "generate xml request body for wfs write transactions."
package_license = "MIT License"

team_email = "itsmehdi97@gmail.com"

version_info = (0, 0, 3)

__author__ = ", ".join("{} <{}>".format(*info) for info in author_info)
__version__ = ".".join(map(str, version_info))